# Supporters

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://support.octoprint.org) -
thanks to everyone who contributed!

## Patrons & Sponsors

  * Andrew Moorby
  * Arnljot Arntsen
  * Ash King
  * BigTreeTech
  * Boris Hussein
  * Brad Jackson
  * BuildBee
  * Christian Petropolis
  * Christian Wolf
  * D Brian Kimmel
  * DeltaMaker 3D Printers
  * Dennis Breining
  * Eric Berry
  * Eric Betts
  * Ernesto Martinez
  * Franziska Kunsmann
  * George Robles
  * Greg Holloway
  * Hog Duske
  * Hopewell Medical Acupuncture Center
  * Hugh Blemings
  * jean-claude migneault
  * Jefferson Hunt
  * Jeremy Cole
  * Joe Pasqua
  * John Gregory Robinson
  * Joshua Wills
  * Justin Kaufman
  * Kaile Riser
  * Kale Stedman
  * Kazuhiro Ogura
  * Kelly C McNiece
  * Kenneth Jiang
  * Kurt Wubbels
  * Kyle Menigoz
  * LA 3D Printer Repair
  * Lee Dohm
  * Loyal Moses
  * Makespace Madrid
  * Mark Walker
  * Michael Aumock
  * Michael Begala
  * Miles Flavel
  * Mosaic Manufacturing
  * Neil R. Goldberg
  * Patrick Glyré
  * Patrick McGinnis
  * Prof Yuh Wen Chen
  * Raise3D
  * Randy C. Will
  * Ranjib Dey
  * Richard McGuire
  * Richard Michaud
  * Rigid3D
  * Robert Gusek
  * Ronald Griehsler
  * Sacha Telgenhof
  * Sebastien Andrivet
  * Stefan Krister
  * Steve Thompson
  * Sven Mueller
  * Ulrich Kempken

and 2147 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel) or via [Github Sponsors](https://github.com/users/foosel/sponsorship)!
